const { ipcRenderer } = require("electron");
const moment = require("moment");
const { loadTempConfiguration, saveConfiguration } = require("../services/config-store");
const startDownloader = require(`./js/start-downloader`);
const $status = document.getElementById("status");
const $form = document.getElementById("downloader");

let timerClear = null;
let isFirstDownload = true;

ipcRenderer.send("set-window-height", document.body.clientHeight);

$form.addEventListener("submit", changeSettings);

setStatus();

function changeSettings(e) {
  e.preventDefault();
  e.stopPropagation();

  goToSettings();
}

function goToSettings(err) {
  if (timerClear !== null) {
    timerClear();
  }

  if (err) {
    location.replace(`settings.html?err=${err.internalCode.code}`);
  } else {
    location.replace(`settings.html`);
  }
}

function setStatus() {
  const config = loadTempConfiguration();

  if (!config || Object.keys(config).length < 5) {
    return goToSettings();
  }

  startDownloader(config, {
    onError: err => {
      if (isFirstDownload) {
        console.error("Redirecting to settings page due to error", err);
        return goToSettings(err);
      } else {
        console.error("Could not download due to error!", err);

        const lastTry = moment();
        $status.classList.add("error");
        $status.querySelector(".last-error").innerHTML = `(${lastTry.format(
          "YYYY-MM-DD HH:mm"
        )}) Letzter Download fehlgeschlagen! Server erreichbar? Speicherort (${config.downloadPath}) beschreibbar?`;

        ipcRenderer.send("make-aware-of-errors", true);
        setTimeout(() => {
          ipcRenderer.send("set-window-height", document.body.clientHeight);
        }, 0);
      }
    },
    onDownload: () => {
      // Save config when first download succeeded
      if (isFirstDownload) {
        saveConfiguration(config);
        isFirstDownload = false;
      }

      $status.querySelector(".last-error").innerHTML = "";
      ipcRenderer.send("make-aware-of-errors", false);
      $status.classList.remove("error");

      const lastSuccessfulDownload = moment();
      $status.querySelector(".interval").innerHTML = `Lade neueste Einsatzliste alle ${config.interval} Minute${
        config.interval !== 1 ? "n" : ""
      }.`;
      $status.querySelector(
        ".last-download"
    ).innerHTML = `<div>Letzter erfolgreicher Download:</div><div style="text-align: center">${lastSuccessfulDownload.format("YYYY-MM-DD HH:mm")}</div>`;

      setTimeout(() => {
        ipcRenderer.send("set-window-height", document.body.clientHeight);
      }, 0);
    }
  }).then(clearCallback => (timerClear = clearCallback));
}
