import path from "path";
import { app, BrowserWindow, ipcMain, Menu, screen } from "electron";

const WINDOW_WIDTH = 500;

// will be called after/in app.on("ready")
export function init(appWindows) {
  if (process.platform === "darwin") {
    Menu.setApplicationMenu(
      Menu.buildFromTemplate([
        {
          label: app.getName(),
          submenu: [
            // { role: "toggleDevTools" }, // DevTools can be made available here
            { role: "quit" }
          ]
        }
      ])
    );
  } else {
    Menu.setApplicationMenu(null);
  }

  let lastBounce = null;
  function makeAwareOfErrorsMac(enable) {
    if (lastBounce !== null) {
      app.dock.cancelBounce(lastBounce);
      lastBounce = null;
    }

    if (enable) {
      lastBounce = app.dock.bounce("critical");
    }
  }

  ipcMain.on("make-aware-of-errors", (event, enable) => {
    if (process.platform === "darwin") {
      makeAwareOfErrorsMac(enable);
    }
  });

  ipcMain.on("set-window-height", (event, height) => {
    if (appWindows.settings !== null) {
      const { x, y, width: oldWidth, height: oldHeight } = appWindows.settings.getContentBounds();
      const bounds = {
        x: parseInt(x + (oldWidth - WINDOW_WIDTH) / 2),
        y: parseInt(y + (oldHeight - height) / 2),
        width: WINDOW_WIDTH,
        height
      };

      if (!appWindows.settings.isVisible()) {
        appWindows.settings.setContentBounds(bounds, false);
        appWindows.settings.show();
      } else {
        appWindows.settings.setContentBounds(bounds, true);
      }
    }
  });
}

export function showDownloaderWindow(appWindows) {
  showWindow(appWindows, `file://${__dirname}/app/index.html`);
}

function showWindow(appWindows, url) {
  const maxHeight = screen.getPrimaryDisplay().workAreaSize.height;

  appWindows.settings = new BrowserWindow({
    backgroundColor: "#16a085",
    backgroundThrottling: false,
    width: WINDOW_WIDTH,
    height: WINDOW_WIDTH,
    maxHeight,
    show: false,
    title: app.getName(),
    icon: path.join(__dirname, "assets/icons/png/64x64.png")
  });

  appWindows.settings.loadURL(url);

  appWindows.settings.on("closed", () => {
    // Dereference the window object, usually you would store windows
    // in an array if your app supports multi windows, this is the time
    // when you should delete the corresponding element.
    appWindows.settings = null;
  });
}
